% Esercizio di modellistica numerica
% Perdita di pressione in un tubazione

L = 6;              % Lunghezza tubazione [m]
Diam = 0.1;         % Diametro tubazione [m]
qmax = 7/3600;      % Portata [m^3/s]
q = linspace(-qmax,qmax,400);


% Parametri della tubazione e fluido
A = pi*Diam^2/4;    % Area della tubazione [m^2]
r = 1.5e-5;         % Rugosita' interna della tubazione [m]
nu = 1.004e-6;      % Viscosita' cinematica [m^2/s]
Ks = 64;            % Fattore di forma
ReL = 2000;         % Coeff. regime laminare
ReT = 4000;         % Coeff. regime turbolento
rho = 1000;         % Densita' [kg/m^3]

% Parametri ottenuti per continuita'
fL = Ks/ReL;
fT = 1/( (-1.8*log10(6.9/ReT+(r/Diam/3.7)^1.11))^2 );

% Inizializzazione
f = zeros(size(q));

% Calcolo Reynolds
Re = abs(q)*Diam/(A*nu);

% Regime laminare
ind1 = find(Re <= ReL);
f(ind1) = Ks./Re(ind1);

% Regime lineare
ind2 = find(Re > ReL & Re < ReT);
f(ind2) = fL + (fT-fL)/(ReT-ReL)*(Re(ind2)-ReL);

% Regime turbolento
ind3 = find(Re >= ReT);
f(ind3) = 1./( (-1.8*log10(6.9./Re(ind3)+(r/Diam/3.7)^1.11)).^2 );

dp = f.*L/Diam*rho/2/A^2.*q.*abs(q);


figure;
h = plot(q(ind1),f(ind1),'r.',q(ind2),f(ind2),'g.',q(ind3),f(ind3),'b.');
set(h,'LineWidth',2);
legend('Reg. Lam.','Reg. Trans.','Reg. Turb.');

figure;
h = plot(q(ind1),dp(ind1),'r.',q(ind2),dp(ind2),'g.',q(ind3),dp(ind3),'b.');
set(h,'LineWidth',2);
legend('Reg. Lam.','Reg. Trans.','Reg. Turb.');

